methods - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# How to install WeeWX

There are a few ways to install WeeWX. Choose the method that best fits your needs.

The installers for Debian, Red Hat, and SUSE use the conventions and software management tools for their respective operating system; these are the fastest and easiest way to get up and running.

- Debian - Ubuntu, Mint, Raspberry Pi OS, Devuan
- Redhat - Fedora, CentOS, Rocky
- SUSE - openSUSE

The pip installer will work on any operating system; use this approach for macOS or one of the BSDs, or if you are using an older operating system. This is also a good approach if you plan to do a lot of customization, or if you are developing a driver, skin, or other extension.

- pip - any operating system

If you want to install WeeWX on a system with very little storage, or if you want to experiment with code that is under development, then you may want to run directly from a clone of the git repository.

- Run from a git repository - any operating system